summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/macros/tests/xmlhandlertests2.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kexi/plugins/macros/tests/xmlhandlertests2.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/plugins/macros/tests/xmlhandlertests2.h')
-rw-r--r--kexi/plugins/macros/tests/xmlhandlertests2.h19
1 files changed, 10 insertions, 9 deletions
diff --git a/kexi/plugins/macros/tests/xmlhandlertests2.h b/kexi/plugins/macros/tests/xmlhandlertests2.h
index 0a3fee3a..d8f92aaf 100644
--- a/kexi/plugins/macros/tests/xmlhandlertests2.h
+++ b/kexi/plugins/macros/tests/xmlhandlertests2.h
@@ -31,6 +31,7 @@ namespace KoMacroTest {
class XMLHandlerTests2 : public KUnitTest::SlotTester
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -68,29 +69,29 @@ namespace KoMacroTest {
/// @internal d-pointer instance.
Private* const d;
- typedef QMap<QString,KoMacro::Variable>::size_type sizetypemap;
- typedef QValueList<KSharedPtr<KoMacro::MacroItem > >::size_type sizetypelist;
+ typedef TQMap<TQString,KoMacro::Variable>::size_type sizetypemap;
+ typedef TQValueList<KSharedPtr<KoMacro::MacroItem > >::size_type sizetypelist;
/**
* Compares a XML-Element with a Macro. Call sub-asserts.
* @p macro The parsen @a Macro.
* @p domelement The given @a QDomElement which is parsen.
* @p isitemsempty Bool for expectation of an empty @a MacroItem -List.
* @p isactionset Bool for expectation that the @a Action -names are equal.
* @p isvariableok QMap of Bools for comparing each @a Variable .
*/
/* void assertMacroContentEqToXML(const KSharedPtr<KoMacro::Macro> macro,
- const QDomElement& elem,
+ const TQDomElement& elem,
const bool isitemsempty,
const bool isactionset,
- const QMap<QString, bool> isvariableok);
+ const TQMap<TQString, bool> isvariableok);
- // Prints a QMap of Variables to kdDebug().
- void printMvariables(const QMap<QString, KSharedPtr<KoMacro::Variable > > mvariables, const QString s);
+ // Prints a TQMap of Variables to kdDebug().
+ void printMvariables(const TQMap<TQString, KSharedPtr<KoMacro::Variable > > mvariables, const TQString s);
*/
/**
* Sub-methods of testParseXML() and testToXML().
* Test the correct parsing of a @a QDomElement into a @a Macro
* respectively expected failure of parsing. Then transform it
* back and compare it.
*/
@@ -68,29 +69,29 @@ namespace KoMacroTest {
* Compares a XML-Element with a Macro. Call sub-asserts.
* @p macro The parsen @a Macro.
- * @p domelement The given @a QDomElement which is parsen.
+ * @p domelement The given @a TQDomElement which is parsen.
* @p isitemsempty Bool for expectation of an empty @a MacroItem -List.
* @p isactionset Bool for expectation that the @a Action -names are equal.
@@ -68,29 +69,29 @@ namespace KoMacroTest {
* @p isitemsempty Bool for expectation of an empty @a MacroItem -List.
* @p isactionset Bool for expectation that the @a Action -names are equal.
- * @p isvariableok QMap of Bools for comparing each @a Variable .
+ * @p isvariableok TQMap of Bools for comparing each @a Variable .
*/
/* void assertMacroContentEqToXML(const KSharedPtr<KoMacro::Macro> macro,
@@ -68,29 +69,29 @@ namespace KoMacroTest {
/**
* Sub-methods of testParseXML() and testToXML().
- * Test the correct parsing of a @a QDomElement into a @a Macro
+ * Test the correct parsing of a @a TQDomElement into a @a Macro
* respectively expected failure of parsing. Then transform it
* back and compare it.